#[repr(C)]pub struct EdlibAlignResult {
pub status: c_int,
pub editDistance: c_int,
pub endLocations: *mut c_int,
pub startLocations: *mut c_int,
pub numLocations: c_int,
pub alignment: *mut c_uchar,
pub alignmentLength: c_int,
pub alphabetLength: c_int,
}Expand description
Container for results of alignment done by edlibAlign() function.
Fields
status: c_intEDLIB_STATUS_OK or EDLIB_STATUS_ERROR. If error, all other fields will have undefined values.
editDistance: c_int-1 if k is non-negative and edit distance is larger than k.
endLocations: *mut c_intArray of zero-based positions in target optimal alignment paths end. If gap after query is penalized, gap counts as part of query (NW), otherwise not. Set to NULL if edit distance is larger than k. If you do not free whole result object using edlibFreeAlignResult(), do not forget to use free().
startLocations: *mut c_intArray of zero-based positions in target where optimal alignment paths start, they correspond to endLocations. If gap before query is penalized, gap counts as part of query (NW), otherwise not. Set to NULL if not calculated or if edit distance is larger than k. If you do not free whole result object using edlibFreeAlignResult(), do not forget to use free().
numLocations: c_intNumber of end (and start) locations.
alignment: *mut c_ucharAlignment is found for first pair of start and end locations. Set to NULL if not calculated. Alignment is sequence of numbers: 0, 1, 2, 3. 0 stands for match. 1 stands for insertion to target. 2 stands for insertion to query. 3 stands for mismatch. Alignment aligns query to target from beginning of query till end of query. If gaps are not penalized, they are not in alignment. If you do not free whole result object using edlibFreeAlignResult(), do not forget to use free().
alignmentLength: c_intLength of alignment.
alphabetLength: c_intNumber of different characters in query and target together.